@@ -11,7 +11,7 @@ BOOST_AUTO_TEST_SUITE( Cairo_ScaledFont )
 
 BOOST_AUTO_TEST_CASE(test_construction)
 {
-  auto face = ToyFontFace::create("sans", FONT_SLANT_NORMAL, FONT_WEIGHT_NORMAL);
+  auto face = ToyFontFace::create("sans", ToyFontFace::Slant::NORMAL, ToyFontFace::Weight::NORMAL);
   Matrix identity;
   cairo_matrix_init_identity(&identity);
   auto font = ScaledFont::create(face, identity, identity, FontOptions());
@@ -24,7 +24,7 @@ BOOST_AUTO_TEST_CASE(test_construction)
 
 BOOST_AUTO_TEST_CASE(test_text_to_glyphs)
 {
-  auto face = ToyFontFace::create("sans", FONT_SLANT_NORMAL, FONT_WEIGHT_NORMAL);
+  auto face = ToyFontFace::create("sans", ToyFontFace::Slant::NORMAL, ToyFontFace::Weight::NORMAL);
   Matrix identity;
   cairo_matrix_init_identity(&identity);
   auto font = ScaledFont::create(face, identity, identity, FontOptions());
@@ -41,7 +41,7 @@ BOOST_AUTO_TEST_CASE(test_text_to_glyphs)
 
 BOOST_AUTO_TEST_CASE(test_scale_matrix)
 {
-  auto face = ToyFontFace::create("sans", FONT_SLANT_NORMAL, FONT_WEIGHT_NORMAL);
+  auto face = ToyFontFace::create("sans", ToyFontFace::Slant::NORMAL, ToyFontFace::Weight::NORMAL);
   Matrix m;
   cairo_matrix_init_scale(&m, 2.0, 4.0);
   auto font = ScaledFont::create(face, m, m, FontOptions());
@@ -57,7 +57,7 @@ BOOST_AUTO_TEST_CASE(test_get_font_face)
   // this is to test for a bug where we were accidentally freeing the resulting
   // font face from a call to ScaledFont::get_font_face() when we didn't hold a
   // reference to it
-  auto face = ToyFontFace::create("sans", FONT_SLANT_NORMAL, FONT_WEIGHT_NORMAL);
+  auto face = ToyFontFace::create("sans", ToyFontFace::Slant::NORMAL, ToyFontFace::Weight::NORMAL);
   Matrix identity;
   cairo_matrix_init_identity(&identity);
   auto font = ScaledFont::create(face, identity, identity, FontOptions());
@@ -74,7 +74,7 @@ BOOST_AUTO_TEST_CASE(test_get_font_face)
 #if defined (CAIRO_HAS_FT_FONT) && defined (CAIRO_HAS_FC_FONT)
 BOOST_AUTO_TEST_CASE(test_ft_scaled_font)
 {
-  // Does not throw an exception. Skip this test for now. /Kjell Ahlstedt 2020-04-30
+  // Does not throw an exception. Skip this test for now. /Kjell Ahlstedt 2020-04-21
   //auto invalid = FcPatternCreate();
   //Cairo::RefPtr<Cairo::FtFontFace> invalid_face;
   //BOOST_CHECK_THROW(invalid_face = Cairo::FtFontFace::create(invalid), std::bad_alloc);
